@@ -2,7 +2,7 @@ import uuid
 from typing import Any, Optional
 
 from sqlalchemy import CHAR
-from sqlalchemy.engine.default import DefaultDialect
+from sqlalchemy.engine import Dialect
 from sqlalchemy.types import TypeDecorator
 
 
@@ -25,22 +25,20 @@ class UUID(TypeDecorator):
             return "CHAR(36)"
         return "CHAR(32)"
 
-    def load_dialect_impl(self, dialect: DefaultDialect) -> Any:
+    def load_dialect_impl(self, dialect: Dialect) -> Any:
         return (
             dialect.type_descriptor(CHAR(36))
             if self.uuid_format == "string"
             else dialect.type_descriptor(CHAR(32))
         )
 
-    def process_bind_param(
-        self, value: uuid.UUID, dialect: DefaultDialect
-    ) -> Optional[str]:
+    def process_bind_param(self, value: uuid.UUID, dialect: Dialect) -> Optional[str]:
         if value is None:
             return value
         return str(value) if self.uuid_format == "string" else "%.32x" % value.int
 
     def process_result_value(
-        self, value: Optional[str], dialect: DefaultDialect
+        self, value: Optional[str], dialect: Dialect
     ) -> Optional[uuid.UUID]:
         if value is None:
             return value
