@@ -29,8 +29,8 @@ def check_node_not_dict_or_not_last_node(
 
     :param part:
     :type part: str
-    :param parts:
-    :type parts: List[str]
+    :param is_last: flag to check if last element
+    :type is_last: bool
     :param current_level: current level of the traversed structure
     :type current_level: Any
     :return: result of the check
@@ -52,7 +52,7 @@ def translate_list_to_dict(  # noqa: CCR001
     Default required key ise Ellipsis like in pydantic.
 
     :param list_to_trans: input list
-    :type list_to_trans: set
+    :type list_to_trans: Union[List, Set]
     :param is_order: flag if change affects order_by clauses are they require special
     default value with sort order.
     :type is_order: bool
@@ -214,21 +214,22 @@ def extract_nested_models(  # noqa: CCR001
     follow = [rel for rel in model_type.extract_related_names() if rel in select_dict]
     for related in follow:
         child = getattr(model, related)
-        if child:
-            target_model = model_type.Meta.model_fields[related].to
-            if isinstance(child, list):
-                extracted.setdefault(target_model.get_name(), []).extend(child)
-                if select_dict[related] is not Ellipsis:
-                    for sub_child in child:
-                        extract_nested_models(
-                            sub_child, target_model, select_dict[related], extracted,
-                        )
-            else:
-                extracted.setdefault(target_model.get_name(), []).append(child)
-                if select_dict[related] is not Ellipsis:
+        if not child:
+            continue
+        target_model = model_type.Meta.model_fields[related].to
+        if isinstance(child, list):
+            extracted.setdefault(target_model.get_name(), []).extend(child)
+            if select_dict[related] is not Ellipsis:
+                for sub_child in child:
                     extract_nested_models(
-                        child, target_model, select_dict[related], extracted,
+                        sub_child, target_model, select_dict[related], extracted
                     )
+        else:
+            extracted.setdefault(target_model.get_name(), []).append(child)
+            if select_dict[related] is not Ellipsis:
+                extract_nested_models(
+                    child, target_model, select_dict[related], extracted
+                )
 
 
 def extract_models_to_dict_of_lists(
